@@ -73,14 +73,15 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
         # b_list.append(max(B_list))
         # uu_list.append(max(u_list))
         # print(b_list, uu_list)
-        for k in range(num_nodes):
-            nodes[k].grads = []
+        # for k in range(num_nodes):
+        #     nodes[k].grads = []
         # print(a)
         # server aggregation and distribution by cluster
-        for i in range(K):
-            server.aggregate(nodes, [j for j in list(range(num_nodes)) if nodes[j].label==i])
-            server.distribute(nodes, [j for j in list(range(num_nodes)) if nodes[j].label==i])
-            cluster_models[k].load_state_dict(server.model.state_dict())
+        for j in range(K):
+            server.aggregate(nodes, [i for i in list(range(num_nodes)) if nodes[i].label==j])
+            server.distribute(nodes, [i for i in list(range(num_nodes)) if nodes[i].label==j])
+            cluster_models[j].load_state_dict(server.model.state_dict())
+        
         # test accuracy
         for j in range(num_nodes):
             nodes[j].local_test()
